@@ -398,6 +398,22 @@ templateRules:
       resourceMatchers:
       - apiVersionKindMatcher: {apiVersion: v1, kind: Pod}
 
+    - path: [spec, fetch, {allIndexes: true}, inline, pathsFrom, {allIndexes: true}, configMapRef]
+      resourceMatchers: &appMatchers
+      - apiVersionKindMatcher: {apiVersion: kappctrl.k14s.io/v1alpha1, kind: App}
+    - path: [spec, template, {allIndexes: true}, ytt, inline, pathsFrom, {allIndexes: true}, configMapRef]
+      resourceMatchers: *appMatchers
+    - path: [spec, template, {allIndexes: true}, ytt, valuesFrom, {allIndexes: true}, configMapRef]
+      resourceMatchers: *appMatchers
+    - path: [spec, template, {allIndexes: true}, helmTemplate, valuesFrom, {allIndexes: true}, configMapRef]
+      resourceMatchers: *appMatchers
+    - path: [spec, template, {allIndexes: true}, cue, valuesFrom, {allIndexes: true}, configMapRef]
+      resourceMatchers: *appMatchers
+
+    - path: [spec, fetch, inline, pathsFrom, {allIndexes: true}, configMapRef]
+      resourceMatchers: &packageRepositoryMatchers
+      - apiVersionKindMatcher: {apiVersion: packaging.carvel.dev/v1alpha1, kind: PackageRepository}
+
 - resourceMatchers:
   - apiVersionKindMatcher: {apiVersion: v1, kind: Secret}
   affectedResources:
@@ -448,6 +464,38 @@ templateRules:
       resourceMatchers:
       - apiVersionKindMatcher: {apiVersion: v1, kind: ServiceAccount}
 
+    - path: [spec, cluster, kubeconfigSecretRef]
+      resourceMatchers: *appMatchers
+    - path: [spec, fetch, {allIndexes: true}, inline, pathsFrom, {allIndexes: true}, secretRef]
+      resourceMatchers: *appMatchers
+    - path: [spec, fetch, {allIndexes: true}, imgpkgBundle, secretRef]
+      resourceMatchers: *appMatchers
+    - path: [spec, fetch, {allIndexes: true}, http, secretRef]
+      resourceMatchers: *appMatchers
+    - path: [spec, fetch, {allIndexes: true}, git, secretRef]
+      resourceMatchers: *appMatchers
+    - path: [spec, fetch, {allIndexes: true}, helmChart, repository, secretRef]
+      resourceMatchers: *appMatchers
+    - path: [spec, template, {allIndexes: true}, ytt, inline, pathsFrom, {allIndexes: true}, secretRef]
+      resourceMatchers: *appMatchers
+    - path: [spec, template, {allIndexes: true}, ytt, valuesFrom, {allIndexes: true}, secretRef]
+      resourceMatchers: *appMatchers
+    - path: [spec, template, {allIndexes: true}, helmTemplate, valuesFrom, {allIndexes: true}, secretRef]
+      resourceMatchers: *appMatchers
+    - path: [spec, template, {allIndexes: true}, cue, valuesFrom, {allIndexes: true}, secretRef]
+      resourceMatchers: *appMatchers
+    - path: [spec, template, {allIndexes: true}, sops, pgp, privateKeySecretRef]
+      resourceMatchers: *appMatchers
+
+    - path: [spec, values, {allIndexes: true}, secretRef]
+      resourceMatchers: &packageInstallMatchers
+      - apiVersionKindMatcher: {apiVersion: packaging.carvel.dev/v1alpha1, kind: PackageInstall}
+    - path: [spec, cluster, kubeconfigSecretRef]
+      resourceMatchers: *packageInstallMatchers
+
+    - path: [spec, fetch, inline, pathsFrom, {allIndexes: true}, secretRef]
+      resourceMatchers: *packageRepositoryMatchers
+
 changeGroupBindings:
 - name: change-groups.kapp.k14s.io/crds
   resourceMatchers: &crdMatchers
@@ -524,12 +572,10 @@ changeGroupBindings:
   - apiVersionKindMatcher: {kind: ServiceAccount, apiVersion: v1}
 
 - name: change-groups.kapp.k14s.io/kapp-controller-app
-  resourceMatchers:
-  - apiVersionKindMatcher: {kind: App, apiVersion: kappctrl.k14s.io/v1alpha1}
+  resourceMatchers: *appMatchers
 
 - name: change-groups.kapp.k14s.io/kapp-controller-packageinstall
-  resourceMatchers:
-  - apiVersionKindMatcher: {kind: PackageInstall, apiVersion: packaging.carvel.dev/v1alpha1}
+  resourceMatchers: *packageInstallMatchers
 
 changeRuleBindings:
 # Insert CRDs before all CRs
