@@ -4,7 +4,7 @@
 package diff
 
 import (
-	ctlres "github.com/k14s/kapp/pkg/kapp/resources"
+	ctlres "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resources"
 )
 
 type ChangePrecalculated struct {
