@@ -7,7 +7,7 @@ import (
 	"fmt"
 	"strings"
 
-	ctlres "github.com/k14s/kapp/pkg/kapp/resources"
+	ctlres "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resources"
 )
 
 type Deleting struct {
