@@ -8,6 +8,7 @@ import (
 	"sort"
 	"strings"
 	"testing"
+	"time"
 
 	"github.com/stretchr/testify/require"
 )
@@ -210,6 +211,149 @@ Succeeded
 	})
 }
 
+func TestSupportUnblockingChanges(t *testing.T) {
+	env := BuildEnv(t)
+	logger := Logger{}
+	kapp := Kapp{t, env.Namespace, env.KappBinaryPath, logger}
+	kubectl := Kubectl{t, env.Namespace, logger}
+
+	name := "test-support-unblocking-changes"
+	crdAppName := "crd-app"
+	cleanUp := func() {
+		kapp.Run([]string{"delete", "-a", name})
+		kapp.Run([]string{"delete", "-a", crdAppName})
+	}
+
+	cleanUp()
+	defer cleanUp()
+
+	crd := `
+---
+apiVersion: apiextensions.k8s.io/v1
+kind: CustomResourceDefinition
+metadata:
+  name: crontabs.stable.example.com
+spec:
+  group: stable.example.com
+  versions:
+    - name: v1
+      served: true
+      storage: true
+      schema:
+        openAPIV3Schema:
+          type: object
+          properties:
+            spec:
+              type: object
+              properties:
+                cronSpec:
+                  type: string
+                image:
+                  type: string
+                replicas:
+                  type: integer
+            status:
+              type: object
+              properties:
+                conditions:
+                  type: array
+                  items:
+                    type: object
+                    properties:
+                      status:
+                        type: string
+                      type:
+                        type: string
+  scope: Namespaced
+  names:
+    plural: crontabs
+    singular: crontab
+    kind: CronTab`
+
+	yaml := `apiVersion: kapp.k14s.io/v1alpha1
+kind: Config
+waitRules:
+- conditionMatchers:
+  - type: Progressing
+    status: "True"
+    unblockChanges: true
+  - type: Available
+    status: "True"
+    success: true
+  resourceMatchers:
+  - apiVersionKindMatcher: {apiVersion: stable.example.com/v1, kind: CronTab}
+---
+apiVersion: "stable.example.com/v1"
+kind: CronTab
+metadata:
+  name: my-new-cron-object-1
+  annotations:
+    kapp.k14s.io/change-group: "cr"
+spec:
+  cronSpec: "* * * * */5"
+  image: my-awesome-cron-image
+status:
+  conditions:
+  - type: Progressing
+    status: "True"
+---
+apiVersion: v1
+kind: ConfigMap
+metadata:
+  name: test-cm
+  annotations:
+    kapp.k14s.io/change-rule: "upsert after upserting cr"`
+
+	go func() {
+		for {
+			time.Sleep(1 * time.Second)
+			exists, err := ClusterResourceExists("ConfigMap", "test-cm", kubectl)
+			require.NoError(t, err, "Expected error to not have occurred")
+			if exists {
+				break
+			}
+		}
+		patch := `[{ "op": "add", "path": "/status/conditions/-", "value": {type: "Available", status: "True"}}]`
+		PatchClusterResource("CronTab", "my-new-cron-object-1", env.Namespace, patch, kubectl)
+	}()
+
+	logger.Section("deploying with supporting unblocking changes", func() {
+		kapp.RunWithOpts([]string{"deploy", "-f", "-", "-a", crdAppName}, RunOpts{IntoNs: true, StdinReader: strings.NewReader(crd)})
+
+		out, _ := kapp.RunWithOpts([]string{"deploy", "-f", "-", "-a", name}, RunOpts{IntoNs: true, StdinReader: strings.NewReader(yaml)})
+
+		out = strings.TrimSpace(replaceSpaces(replaceAgeStr(replaceTarget(replaceTs(out)))))
+		expectedOutput := strings.TrimSpace(replaceSpaces(`Changes
+
+Namespace  Name                  Kind       Age  Op      Op st.  Wait to    Rs  Ri  $
+kapp-test  my-new-cron-object-1  CronTab    -    create  -       reconcile  -   -  $
+^          test-cm               ConfigMap  -    create  -       reconcile  -   -  $
+
+Op:      2 create, 0 delete, 0 update, 0 noop, 0 exists
+Wait to: 2 reconcile, 0 delete, 0 noop
+
+<replaced>: ---- applying 1 changes [0/2 done] ----
+<replaced>: create crontab/my-new-cron-object-1 (stable.example.com/v1) namespace: kapp-test
+<replaced>: ---- waiting on 1 changes [0/2 done] ----
+<replaced>: ongoing: reconcile crontab/my-new-cron-object-1 (stable.example.com/v1) namespace: kapp-test
+<replaced>:  ^ Allowing blocked changes to proceed: Encountered condition Progressing == True: $
+<replaced>: ---- applying 1 changes [1/2 done] ----
+<replaced>: create configmap/test-cm (v1) namespace: kapp-test
+<replaced>: ---- waiting on 2 changes [0/2 done] ----
+<replaced>: ok: reconcile configmap/test-cm (v1) namespace: kapp-test
+<replaced>: ---- waiting on 1 changes [1/2 done] ----
+<replaced>: ok: reconcile crontab/my-new-cron-object-1 (stable.example.com/v1) namespace: kapp-test
+<replaced>:  ^ Encountered successful condition Available == True:  (message: )
+<replaced>: ---- applying complete [2/2 done] ----
+<replaced>: ---- waiting complete [2/2 done] ----
+
+Succeeded
+`))
+
+		require.Contains(t, out, expectedOutput)
+	})
+}
+
 func replaceTs(result string) string {
 	return regexp.MustCompile("\\d{1,2}:\\d{1,2}:\\d{1,2}(AM|PM)").ReplaceAllString(result, "<replaced>")
 }
